import request from '@map/utils/request'
export function costlist(layersId){
  return request({
     url:'/pipe/cost/list/'+layersId,
     method: 'get'
  })
}
//重新识别
export function recognitionreload(params){
  return request({
     url:'/pipe/algorithm/recognition/reload',
     method: 'post',
     params
  })
}
//加载已有
export function recognitionload(params){
  return request({
     url:'/pipe/algorithm/recognition/load',
     method: 'post',
     params
  })
}
//新加载已有
export function recognitionList(params){
  return request({
     url:'/pipe/recognition/list',
     method: 'get',
     params
  })
}
//重新布线
export function pipelinereload(params){
  return request({
     url:'/pipe/algorithm/pipeline/reload',
     method: 'post',
     params
  })
}
//布线加载已有
export function pipelineload(params){
  return request({
     url:'/pipe/algorithm/pipeline/load',
     method: 'post',
     params
  })
}
export function writeCsv(layersId){
  return request({
     url:'pipe/algorithm/writeCsv/'+layersId,
     method: 'post',

  })
}
export function layersList(){
  return request({
     url:'/pipe/layers/list',
     method: 'get',
  })
}

export function sseClose(id){
  return request({
     url:'/sse/close/'+id,
     method: 'get',
  })
}
//检测是否有上传
export function checkFile(md5){
  return request({
    url:'/check?md5='+md5,
    method: 'get',
  })
}
//上传切片
export function uploadRequest(data){
  return request({
    url:'/upload/chunk',
    method: 'post',
    data,
    headers:{
      'Content-Type': 'multipart/form-data'
    },
    isNosessionObj:true,
    isNoLoading:true
  })
}
//上传
export function layersAdd(data){
  return request({
     url:'/pipe/layers',
     method: 'post',
     data

  })
}
//识别算法数据编辑
export function recognUpdate(data){
  return request({
     url:'/pipe/recognition/update',
     method: 'post',
     data

  })
}
//布线算法数据编辑
export function pipelineUpdate(data){
  return request({
     url:'/pipe/pipeline/updateData',
     method: 'post',
     data

  })
}
//获取散点高程信息
export function findSkeleton(profilesId){
  return request({
     url:'/pipe/algorithm/findSkeleton/'+profilesId,
     method: 'get',

  })
}
